@@ -6,6 +6,7 @@ from braintree.address_gateway import AddressGateway
 from braintree.amex_express_checkout_card import AmexExpressCheckoutCard
 from braintree.android_pay_card import AndroidPayCard
 from braintree.apple_pay_card import ApplePayCard
+from braintree.apple_pay_gateway import ApplePayGateway
 from braintree.braintree_gateway import BraintreeGateway
 from braintree.client_token import ClientToken
 from braintree.configuration import Configuration
@@ -42,9 +43,11 @@ from braintree.partner_merchant import PartnerMerchant
 from braintree.payment_instrument_type import PaymentInstrumentType
 from braintree.payment_method import PaymentMethod
 from braintree.payment_method_nonce import PaymentMethodNonce
+from braintree.payment_method_parser import parse_payment_method
 from braintree.paypal_account import PayPalAccount
 from braintree.plan import Plan
 from braintree.plan_gateway import PlanGateway
+from braintree.processor_response_types import ProcessorResponseTypes
 from braintree.resource_collection import ResourceCollection
 from braintree.risk_data import RiskData
 from braintree.samsung_pay_card import SamsungPayCard
