@@ -20,6 +20,7 @@ from braintree.ids_search import IdsSearch
 from braintree.exceptions.not_found_error import NotFoundError
 from braintree.resource_collection import ResourceCollection
 from braintree.transparent_redirect import TransparentRedirect
+from braintree.samsung_pay_card import SamsungPayCard
 
 class Customer(Resource):
     """
@@ -73,6 +74,7 @@ class Customer(Resource):
     def __repr__(self):
         detail_list = [
             "id",
+            "graphql_id",
             "company",
             "created_at",
             "email",
@@ -272,3 +274,7 @@ class Customer(Resource):
         if "masterpass_cards" in attributes:
             self.masterpass_cards = [MasterpassCard(gateway, masterpass_card) for masterpass_card in self.masterpass_cards]
             self.payment_methods += self.masterpass_cards
+
+        if "samsung_pay_cards" in attributes:
+            self.samsung_pay_cards = [SamsungPayCard(gateway, samsung_pay_card) for samsung_pay_card in self.samsung_pay_cards]
+            self.payment_methods += self.samsung_pay_cards
