@@ -476,6 +476,7 @@ class ErrorCodes(object):
         AmountIsRequired = "81502"
         AmountIsTooLarge = "81528"
         AmountMustBeGreaterThanZero = "81531"
+        AmountNotSupportedByProcessor = "815193"
         BillingAddressConflict = "91530"
         CannotBeVoided = "91504"
         CannotCancelRelease = "91562"
@@ -553,6 +554,7 @@ class ErrorCodes(object):
         ProcessorAuthorizationCodeIsInvalid = "81520"
         ProcessorDoesNotSupportAuths = "915104"
         ProcessorDoesNotSupportCredits = "91546"
+        ProcessorDoesNotSupportMotoForCardType = "915195"
         ProcessorDoesNotSupportPartialSettlement = "915102"
         ProcessorDoesNotSupportUpdatingOrderId = "915107"
         ProcessorDoesNotSupportUpdatingDescriptor = "915108"
@@ -561,6 +563,8 @@ class ErrorCodes(object):
         PurchaseOrderNumberIsInvalid = "91548"
         PurchaseOrderNumberIsTooLong = "91537"
         RefundAmountIsTooLarge = "91521"
+        RefundAuthHardDeclined = "915200"
+        RefundAuthSoftDeclined = "915201"
         ServiceFeeAmountCannotBeNegative = "91554"
         ServiceFeeAmountFormatIsInvalid = "91555"
         ServiceFeeAmountIsTooLarge = "91556"
