@@ -33,6 +33,7 @@ class PaymentMethod(Resource):
             "verification_merchant_account_id",
             "verify_card",
             "verification_amount",
+            "verification_account_type",
             {
                 "adyen": [
                     "overwrite_brand",
@@ -64,6 +65,7 @@ class PaymentMethod(Resource):
             "number",
             "payment_method_nonce",
             "paypal_refresh_token",
+            # NEXT_MAJOR_VERSION remove this parameter as it's been ignored in the gateway
             "paypal_vault_without_upgrade",
             "token",
             {
@@ -98,6 +100,7 @@ class PaymentMethod(Resource):
                     "verify_card",
                     "verification_amount",
                     "verification_merchant_account_id",
+                    "verification_account_type",
                     "venmo_sdk_session",
                     {
                         "adyen": [
